hyperiax.models.functional package
==================================

Submodules
----------

hyperiax.models.functional.reducers module
------------------------------------------

.. automodule:: hyperiax.models.functional.reducers
   :members:
   :undoc-members:
   :show-inheritance:

hyperiax.models.functional.shortup module
-----------------------------------------

.. automodule:: hyperiax.models.functional.shortup
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: hyperiax.models.functional
   :members:
   :undoc-members:
   :show-inheritance:
